import { ErrorHandler, INodeLocation } from "@typescript-nameof/common";
import { Diagnostic, Node } from "typescript";
import { ITypeScriptContext } from "../Transformation/ITypeScriptContext.cjs";
import { TypeScriptFeatures } from "../Transformation/TypeScriptFeatures.cjs";
/**
 * Provides the functionality to report errors to a TypeScript compiler.
 *
 * @template TFeatures
 * The type of the features for the error handler.
 */
export declare class TypeScriptErrorHandler<TFeatures extends TypeScriptFeatures = TypeScriptFeatures> extends ErrorHandler<Node, ITypeScriptContext> {
    /**
     * A set of features for the error handler.
     */
    private features;
    /**
     * Initializes a new instance of the {@linkcode TypeScriptErrorHandler}.
     *
     * @param features
     * A set of features for the error handler.
     */
    constructor(features: TFeatures);
    /**
     * Gets a set of features for the error handler.
     */
    protected get Features(): TFeatures;
    /**
     * Reports the specified {@linkcode error}.
     *
     * @param location
     * The location of the specified {@linkcode node}.
     *
     * @param item
     * The item related to the specified {@linkcode error}.
     *
     * @param context
     * The context of the operation.
     *
     * @param error
     * The error to report.
     */
    Report(location: INodeLocation, item: Node, context: ITypeScriptContext, error: Error): void;
    /**
     * Creates a diagnostic for the specified {@linkcode error}.
     *
     * @param node
     * The node related to the error.
     *
     * @param context
     * The context of the operation.
     *
     * @param error
     * The error to create a diagnostic for.
     *
     * @returns
     * The diagnostic for the specified {@linkcode error}.
     */
    protected GetDiagnostic(node: Node, context: ITypeScriptContext, error: Error): Diagnostic;
    /**
     * Reports the specified {@linkcode diagnostic}.
     *
     * @param location
     * The location of the specified {@linkcode node}.
     *
     * @param item
     * The node related to the error.
     *
     * @param context
     * The context of the operation.
     *
     * @param diagnostic
     * The diagnostic to report.
     *
     * @param error
     * The original error.
     */
    protected ReportDiagnostic(location: INodeLocation, item: Node, context: ITypeScriptContext, diagnostic: Diagnostic, error: Error): void;
}
