import { IAdapter, TransformerBase } from "@typescript-nameof/common";
import { Node, SourceFile, TransformationContext, TransformerFactory } from "typescript";
import { ITypeScriptContext } from "./ITypeScriptContext.cjs";
import { TransformHook } from "./TransformHook.cjs";
import { TypeScriptFeatures } from "./TypeScriptFeatures.cjs";
/**
 * Provides a basic implementation of a TypeScript transformer.
 *
 * @template TFeatures
 * The type of the features for the transformer.
 */
export declare abstract class TypeScriptTransformerBase<TFeatures extends TypeScriptFeatures> extends TransformerBase<Node, Node, ITypeScriptContext, TFeatures> {
    /**
     * Initializes a new instance of the {@linkcode TypeScriptTransformerBase} class.
     *
     * @param features
     * The features of the transformer.
     */
    constructor(features: TFeatures);
    /**
     * Gets a component for creating a transformer.
     */
    get Factory(): TransformerFactory<SourceFile>;
    /**
     * Gets a factory with a pre-defined {@linkcode context}.
     *
     * @param postTransformHook
     * A hook to execute after transforming a node.
     *
     * @returns
     * A newly created factory with a pre-defined {@linkcode context}.
     */
    GetFactory(postTransformHook?: TransformHook): TransformerFactory<SourceFile>;
    /**
     * @inheritdoc
     *
     * @returns
     * The newly created adapter.
     */
    protected InitializeAdapter(): IAdapter<Node, Node, ITypeScriptContext>;
    /**
     * Transforms the specified {@linkcode file}.
     *
     * @param file
     * The file to transform.
     *
     * @param tsContext
     * The context of the typescript transformation.
     *
     * @param postTransformHook
     * A hook to execute after transforming a node.
     *
     * @returns
     * The transformed representation of the specified {@linkcode file}.
     */
    protected VisitSourceFile(file: SourceFile, tsContext: TransformationContext, postTransformHook?: TransformHook): SourceFile;
    /**
     * Transforms the specified {@linkcode node}.
     *
     * @param node
     * The node to transform.
     *
     * @param context
     * The context of the operation.
     *
     * @param tsContext
     * The context of the typescript transformation.
     *
     * @returns
     * The transformed representation of the specified {@linkcode node}.
     */
    protected VisitNode<T extends Node>(node: T, context: ITypeScriptContext, tsContext: TransformationContext): T;
}
