"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceInText = void 0;
const ts = __importStar(require("typescript"));
const TypeScriptTransformer_cjs_1 = require("../Transformation/TypeScriptTransformer.cjs");
const printer = ts.createPrinter();
/**
 * Transforms the file with the specified {@link fileName `fileName`}.
 *
 * @param fileName
 * The name of the file to transform.
 *
 * @param fileText
 * The text of the file to transform.
 *
 * @returns
 * The result of the substitution.
 */
function replaceInText(fileName, fileText) {
    // unofficial pre-2.0 backwards compatibility for this method
    if (!fileText) {
        fileText = fileName;
        fileName = "/file.tsx"; // assume tsx
    }
    let sourceFile = ts.createSourceFile(fileName, fileText, ts.ScriptTarget.Latest, false);
    let transformations = [];
    let transformer = new TypeScriptTransformer_cjs_1.TypeScriptTransformer();
    ts.transform(sourceFile, [
        transformer.GetFactory((oldNode, newNode) => {
            if (oldNode !== newNode) {
                let nodeStart = oldNode.getStart(sourceFile);
                let lastTransformation = transformations[transformations.length - 1];
                // remove the last transformation if it's nested within this transformation
                if (lastTransformation !== undefined && lastTransformation.start > nodeStart) {
                    transformations.pop();
                }
                transformations.push({
                    start: nodeStart,
                    end: oldNode.end,
                    text: printer.printNode(ts.EmitHint.Unspecified, newNode, sourceFile)
                });
            }
        })
    ]);
    if (transformations.length === 0) {
        return { replaced: false };
    }
    else {
        let finalText = "";
        let lastPos = 0;
        for (const transform of transformations) {
            finalText += fileText.substring(lastPos, transform.start);
            finalText += transform.text;
            lastPos = transform.end;
        }
        finalText += fileText.substring(lastPos);
        return { fileText: finalText, replaced: true };
    }
}
exports.replaceInText = replaceInText;
//# sourceMappingURL=replaceInText.cjs.map